@@ -35,17 +35,11 @@ if (getRversion() >= "2.15.1") utils::globalVariables(c(":="))
 #'   for internal use of `egor` and should not be used to store
 #'   persistent data. Other `.`-led column names may be reserved in
 #'   the future.
-#' @return Returns an [`egor`] object. An [`egor`] object is a [`tibble`] whose
-#'   top-level columns store the ego attributes, and which has two
-#'   special nested columns: `.alts`, containing, for each row (ego) a
-#'   table of that ego's alter attributes and `.aaties`, a table
-#'   containing that ego's alter--alter ties, if observed.
-#'
-#'   If alter-alter ties are observed, `.alts` also has a column
-#'   `.altID` giving a unique (within each ego) ID of the alter, by
-#'   which the alter can be identified in the `.aaties` table for that
-#'   ego. `.aaties`, in turn, has columns `.srcID` and `.tgtID` that
-#'   contain the source and the target of the alter-alter relation.
+#' @return Returns an [`egor`] object, which is a `named list` with three 
+#'    `tibble data.frames`: ego, alter and aatie (alter-alter ties).
+#'    Each data set has an `.egoID` column, that groups the data belonging to one
+#'    ego. Additionally the alter data has an `.alterID` column, that links to 
+#'    the columns `.srcID` and `.tgtID` in the alter-alter tie data.
 #'
 #'   In addition, `egor` has two attributes: `ego_design`, containing an
 #'   object returned by [srvyr::as_survey_design()] specifying the sampling
@@ -54,6 +48,7 @@ if (getRversion() >= "2.15.1") utils::globalVariables(c(":="))
 #'   nominated. See the argument above for currently implemented
 #'   settings.
 #' @keywords ego-centered network analysis
+#' @seealso [as_tibble()] for extracting ego, alter, and alter--alter tables, as [`tibble`]s or as `srvyr`'s [`tbl_svy`] surveys.
 #' @examples 
 #' data("egos32")
 #' data("alters32")
@@ -82,6 +77,42 @@ egor <- function(alters,
   # Modify ID name list
 
   IDv <- modifyList(eval(formals()$ID.vars), ID.vars)
+  
+  # Make sure that all ID variables are of the same type
+  
+  ## all numeric?
+  
+  id_vars <- list(
+    alters[[IDv$ego]],
+    alters[[IDv$alter]],
+    egos[[IDv$ego]],
+    aaties[[IDv$ego]],
+    aaties[[IDv$source]],
+    aaties[[IDv$target]]
+  )
+  
+  id_vars <- id_vars[!is.null(id_vars)]
+  
+  all_numeric <- 
+    all(purrr::map_lgl(id_vars, is.numeric))
+  
+  ## not all numeric: change all to character
+  
+  if (!all_numeric & !all(purrr::map_lgl(id_vars, is.character))) {
+    alters[[IDv$ego]] <- as.character(alters[[IDv$ego]])
+    
+    if (!is.null(alters[[IDv$alter]]))
+      alters[[IDv$alter]] <- as.character(alters[[IDv$alter]])
+    
+    if (!is.null(egos)) egos[[IDv$ego]] <- as.character(egos[[IDv$ego]])
+    
+    if (!is.null(aaties)) {
+      aaties[[IDv$ego]] <- as.character(aaties[[IDv$ego]])
+      aaties[[IDv$source]] <- as.character(aaties[[IDv$source]])
+      aaties[[IDv$target]] <- as.character(aaties[[IDv$target]])
+    }
+
+  }
 
   # Check for reserved column names
   
@@ -133,7 +164,7 @@ egor <- function(alters,
   # Alter-Alter
   
   if (is.null(aaties)) {
-    aaties <- tibble(.srcID = 0, .tgtID = 0)[0,]
+    aaties <- tibble(.egoID = 0, .srcID = 0, .tgtID = 0)[0,]
   } else {
     if (!is_tibble(aaties)) {
       aaties <- as_tibble(aaties)
@@ -150,15 +181,31 @@ egor <- function(alters,
   # Check ID consistency
   
   if (any(duplicated(egos[[IDVARS$ego]])))
-    stop("Duplicated ego IDs in ego data.",
+    stop("Duplicated ego IDs in `ego` data.",
          call. = FALSE)
   
   if (!all(alters[[IDVARS$ego]] %in% egos[[IDVARS$ego]]))
-    stop("There is at least one ego ID in the alter data with no corresponding entry in the ego data.",
+    stop("There is at least one ego ID in the `alter` data with no corresponding entry in the `ego` data.",
          call. = FALSE)
   
   if (!all(c(aaties[[IDVARS$ego]] %in% egos[[IDVARS$ego]])))
-    stop("There is at least one ego ID in the alter-alter data with no corresponding entry in the alter data.",
+    stop("There is at least one ego ID in the `alter-alter` data with no corresponding entry in the `alter` data.",
+         call. = FALSE)
+  
+  alter_aatie_ids_consistent <- 
+    purrr::map_lgl(egos[[IDVARS$ego]],
+                   function(x){
+                     sym_ego_id <- rlang::sym(IDVARS$ego)
+                     alter <- filter(alters, !!sym_ego_id == x)
+                     aatie <- filter(aaties, !!sym_ego_id == x)
+                     
+                     all(c(aatie[[IDVARS$source]], 
+                           aatie[[IDVARS$target]]) %in% alter[[IDVARS$alter]])
+                   })
+  
+  if(!all(alter_aatie_ids_consistent))
+    stop("There is at least one alter referenced in the `alter-alter` data that is not listed in the `alter` data. Errors were found for egos: ", 
+         paste(egos[[IDVARS$ego]][!alter_aatie_ids_consistent], collapse = " "),
          call. = FALSE)
   
   # Return
@@ -182,8 +229,6 @@ egor <- function(alters,
 #' @export
 summary.egor <- function(object, ...) {
   
-  # TODO: return tibble instead of using cat for output?!? 
-  
   # Network count
   nc <- nrow(object$ego)
   
@@ -192,14 +237,32 @@ summary.egor <- function(object, ...) {
   max_nts <- max(table(object$alter$.egoID))
   avg_nts <- mean(table(object$alter$.egoID))
   
+  if(has_ego_design(object)) {
+    object$ego$variables$avg_nts <- avg_nts
+    avg_nts <- survey::svymean(~avg_nts, object$ego)
+  }
+  
   # Total number of alters
   alts_count <- nrow(object$alter)
   
   # Average density
   if ("aatie" %in% names(object)) 
-    dens <- mean(ego_density(object = object), na.rm = TRUE)
-  else
-    dens <- NULL
+    if(has_ego_design(object)) {
+      
+      errwd_value <- 
+        getOption("egor.return.results.with.design")
+      options(egor.return.results.with.design = TRUE)
+      
+      dens <- ego_density(object)
+      dens <- survey::svymean(~density, dens)
+      
+      options(egor.return.results.with.design = errwd_value)
+      
+    } else {
+      
+      dens <- mean(ego_density(object = object)$density, na.rm = TRUE)
+      
+      } else dens <- NULL
   
   cat(paste(nc, "Egos/ Ego Networks",
             paste0( "\n", alts_count, " Alters"),
@@ -209,43 +272,69 @@ summary.egor <- function(object, ...) {
   if (!is.null(dens)) cat(paste("Average Density", dens, "\n"))
 
   # Meta Data
-  cat("\nEgo sampling design:\n")
-#' @importFrom utils capture.output
-  writeLines(paste("  ", capture.output(print(object$egos))), sep = "")
-
+  if(has_ego_design(object)) {
+    cat("\nEgo sampling design:\n")
+    #' @importFrom utils capture.output
+    print(ego_design(object))
+  }
+  
   cat("Alter survey design:\n")
   cat("  Maximum nominations:", attr(object, "alter_design")$max,"\n")
 }
 
 #' @rdname summary.egor
+#' @param n.active `Numeric`. Number of rows to print for active data level.
+#' @param n.inactive `Numeric`. Number of rows to print for inactive data levels.
 #' @export
 #' @method print egor
 #' @import tibble
 #' @importFrom dplyr group_vars
-print.egor <- function(x, ..., n = 3) {
+print.egor <- function(x,
+                       ...,
+                       n.active = getOption("egor.rows_active_level"),
+                       n.inactive = getOption("egor.rows_inactive_level")) {
   class(x) <- "list"
   active_lgl <- attr(x, "active") == names(x)
-  y <- c(x[active_lgl],
-         x[!active_lgl])
   
-  purrr::pwalk(list(y, names(y), c(TRUE, FALSE, FALSE)), function(x, y, z) {
-    design <- NULL
-    if ("tbl_svy" %in% class(x)) {
-      x <- x$variables
-      design <- " with survey design"
-    }
-      
-    tcm <- tibble::trunc_mat(x, n = min(n,nrow(x)))
-    
-    if (is_grouped_df(x)) tcm$summary <- paste(tcm$summary, collapse = " ")
-    
-    if (z)
-      cat(paste0("# ", toupper(y), " data", design ," (active): ", tcm$summary[1], "\n"))
-    else
-      cat(paste0("# ", toupper(y), " data", design ,": ", tcm$summary[1], "\n"))
-
-    print(tcm$mcf)
-  })
+  if (getOption("egor.active_level_to_top")) {
+    data_levels <- c(x[active_lgl],
+                     x[!active_lgl])
+    active_lgl <- c(TRUE, FALSE, FALSE)
+  } else {
+    data_levels <- x
+  }
+  
+  purrr::pwalk(list(data_levels,
+                    names(data_levels),
+                    active_lgl),
+               function(data_level, level_name, active) {
+                 design <- NULL
+                 if ("tbl_svy" %in% class(data_level)) {
+                   data_level <- data_level$variables
+                   design <- " with survey design"
+                 }
+                 
+                 if (active) tcm <- tibble::trunc_mat(data_level, n = min(n.active, nrow(data_level)))
+                 else tcm <- tibble::trunc_mat(data_level, n = min(n.inactive, nrow(data_level)))
+                 
+                 if (is_grouped_df(data_level))
+                   tcm$summary <- paste(tcm$summary, collapse = " ")
+                 
+                 if (active)
+                   cat(paste0(
+                     "# ",
+                     toupper(level_name),
+                     " data",
+                     design ,
+                     " (\033[32mactive\033[39m): ",
+                     tcm$summary[1],
+                     "\n"
+                   ))
+                 else
+                   cat(paste0("# ", toupper(level_name), " data", design , ": ", tcm$summary[1], "\n"))
+                 
+                 print(tcm$mcf)
+               })
   invisible(x)
 }
 
@@ -314,37 +403,3 @@ as.egor.nested_egor <- function(x, ID.vars = list(
     )
   }
 }
-
-#' @method as_tibble egor
-#' @export
-as_tibble.egor <- function(x, 
-                           ..., 
-                           include.ego.vars = FALSE, 
-                           include.alter.vars = FALSE){
-  res <- as_tibble(x[[attr(x, "active")]])
-  
-  if (include.ego.vars & attr(x, "active") != "ego") {
-    
-    if (has_ego_design(x)) {
-      names(x$ego$variables)[names(x$ego$variables) != ".egoID"] <-
-        paste0(names(x$ego$variables)[names(x$ego$variables) != ".egoID"] , "_ego")
-      res <- full_join(res, x$ego$variables, by = ".egoID")
-    }else{
-      names(x$ego)[names(x$ego) != ".egoID"] <-
-        paste0(names(x$ego)[names(x$ego) != ".egoID"] , "_ego")
-      res <- full_join(res, x$ego, by = ".egoID")
-    }
-  }
-
-  if (include.alter.vars & attr(x, "active") == "aatie") {
-    res <- left_join(res, 
-                     x$alter, 
-                     by = c(".egoID", ".srcID" = ".altID"))
-    res <- left_join(res, 
-                     x$alter, 
-                     by = c(".egoID", ".tgtID" = ".altID"),
-                     suffix = c("_src","_tgt"))
-  }
-  
-  res
-}
